aboutsummaryrefslogtreecommitdiffstats
path: root/src/rlx_dscv_util.erl
diff options
context:
space:
mode:
Diffstat (limited to 'src/rlx_dscv_util.erl')
-rw-r--r--src/rlx_dscv_util.erl6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/rlx_dscv_util.erl b/src/rlx_dscv_util.erl
index 68dcb68..3d90b08 100644
--- a/src/rlx_dscv_util.erl
+++ b/src/rlx_dscv_util.erl
@@ -21,13 +21,13 @@
%%% @doc This provider uses the lib_dir setting of the state. It searches the
%%% Lib Dirs looking for all OTP Applications that are available. When it finds
%%% those OTP Applications it loads the information about them and adds them to
-%%% the state of available apps. This implements the rcl_provider behaviour.
--module(rcl_dscv_util).
+%%% the state of available apps. This implements the rlx_provider behaviour.
+-module(rlx_dscv_util).
-export([do/2,
format_error/1]).
--include_lib("relcool/include/relcool.hrl").
+-include_lib("relx/include/relx.hrl").
%%============================================================================
%% Types